import os
from datetime import date
import subprocess

# 配置pip源
subprocess.check_call(['pip', 'config', 'set', 'global.index-url', 'https://pypi.tuna.tsinghua.edu.cn/simple'])

# 尝试导入cv2库，如果失败，则自动安装
try:
    import cv2
except ImportError:
    subprocess.check_call(['pip', 'install', 'opencv-python'])
    import cv2

folder_path = r""  # 视频素材地址 支持视频和图片

# 如果文件夹路径为空，则获取脚本所在目录地址
if not folder_path:
    script_dir = os.path.dirname(os.path.abspath(__file__))
    folder_path = script_dir

# 加载素材 获取文件夹下的所有素材
def loading_video_lst(folder_path):
    video_files = []
    for root, dirs, files in os.walk(folder_path):
        for file in files:
            if file.lower().endswith((".MP4", ".mp4", ".avi", ".mkv", ".mov", ".jpg", ".png", ".jpeg")):
                video_files.append(os.path.join(root, file))
    return video_files


# 审核素材
def get_times(video_files):
    seconds = 0
    video = 0
    img = 0
    times =""
    for video_file in video_files:
        if video_file.endswith((".MP4", ".mp4", ".avi", ".mkv", ".mov", ".AVI")):
            cap = cv2.VideoCapture(video_file)
            fps = cap.get(cv2.CAP_PROP_FPS)
            frame_count = cap.get(cv2.CAP_PROP_FRAME_COUNT)
            duration = frame_count / fps
            print(video_file, f"该视频为{duration}秒")
            seconds += duration
            video += 1
            cap.release()
        else:
            img += 1
    # 计算视频时长
    m, s = divmod(seconds, 60)
    h, m = divmod(m, 60)
    times = "%02d:%02d:%02d" % (h, m, s)

    return video, img, seconds, times


if __name__ == '__main__':
    # 判断folder_path是否为空，如果为空则获取脚本所在目录地址
    if not folder_path:
        script_dir = os.path.dirname(os.path.abspath(__file__))
        folder_path = script_dir
    
    video_files = loading_video_lst(folder_path)
    video, img, seconds, times = get_times(video_files)
    
    # 获取保存的文档名
    today = date.today()
    doc_name = f"{os.path.basename(folder_path)}-{today.strftime('%m%d')}.txt"
    
    # 设置保存的文档路径
    save_folder = os.path.join(folder_path, "素材审核")
    os.makedirs(save_folder, exist_ok=True)
    output_path = os.path.join(save_folder, doc_name)
    
    # 保存结果到txt文件
    with open(output_path, "w") as file:
        file.write(f"素材审核完毕, 共计视频数量{video}个，图片{img}张，视频总时长{seconds}秒,合计{times}")
    
    print(f"素材审核完毕, 共计视频数量{video}个，图片{img}张，视频总时长{seconds}秒，合计{times}，结果已保存至 {output_path}")
